@@ -1,4 +1,4 @@
-# Copyright (c) 2007, 2019, Oracle and/or its affiliates. All rights reserved.
+# Copyright (c) 2007, 2020, Oracle and/or its affiliates.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License, version 2.0,
@@ -22,7 +22,7 @@
 from mforms import newButton, newLabel, newBox, newCheckBox, newTextBox, Utilities
 import mforms
 
-from wb_common import dprint_ex, OperationCancelledError, to_encodedString
+from wb_common import dprint_ex, OperationCancelledError, to_encodedString, to_unicode
 import datetime
 from wb_admin_utils import no_remote_admin_warning_label
 
@@ -33,7 +33,7 @@ from wb_admin_utils import weakcb, WbAdminTabBase, WbAdminValidationConnection,
 
 class WbAdminValidationRemoteAccess(WbAdminValidationBase):
     def __init__(self, instance_info):
-        WbAdminValidationBase.__init__(self, "")
+        super().__init__()
         
         self._instance_info = instance_info
 
@@ -274,11 +274,11 @@ class WbAdminConfigurationStartup(WbAdminTabBase):
             try:
                 self.error_log_reader = ErrorLogFileReader(self._ctrl_be, self.server_profile.error_log_file_path)
                 self.error_log_position = self.error_log_reader.file_size
-            except OperationCancelledError, e:
+            except OperationCancelledError as e:
                 self.startup_msgs_log.append_text_with_encoding("Cancelled password input to open error log file: %s\n" % e,
                                                               self._ctrl_be.server_helper.cmd_output_encoding, True)
                 raise
-            except Exception, e:
+            except Exception as e:
                 self.startup_msgs_log.append_text_with_encoding("Could not open error log file: %s\n" % e,
                                                                 self._ctrl_be.server_helper.cmd_output_encoding, True)
 
@@ -294,7 +294,13 @@ class WbAdminConfigurationStartup(WbAdminTabBase):
                 if records:
                     self.startup_msgs_log.append_text_with_encoding('\nFROM %s:\n' % self.server_profile.error_log_file_path,
                                                                     self._ctrl_be.server_helper.cmd_output_encoding, True)
-                    self.startup_msgs_log.append_text_with_encoding('    '+'\n    '.join( ["  ".join(line) for line in records]) + '\n',
+                    
+                    log_lines = []
+                    for line in records:
+                        record_string = "  ".join(to_unicode(log_piece) for log_piece in line)
+                        log_lines.append(record_string)
+                    log_output = "\n    ".join(log_lines)
+                    self.startup_msgs_log.append_text_with_encoding('    ' + log_output + '\n',
                                                                     self._ctrl_be.server_helper.cmd_output_encoding, True)
 
 
@@ -324,7 +330,7 @@ class WbAdminConfigurationStartup(WbAdminTabBase):
                         self.start_stop_btn.set_enabled(True)
                         self.refresh_button.set_enabled(True)
                         return
-                except Exception, exc:
+                except Exception as exc:
                     if self._ctrl_be.target_version and self._ctrl_be.target_version.is_supported_mysql_version_at_least(5, 7, 5):
                         self.offline_mode_btn.show(True)
 
@@ -344,7 +350,7 @@ class WbAdminConfigurationStartup(WbAdminTabBase):
                         self.start_stop_btn.set_enabled(True)
                         self.refresh_button.set_enabled(True)
                         return
-                except Exception, exc:
+                except Exception as exc:
                     self.start_stop_btn.set_enabled(True)
                     self.refresh_button.set_enabled(True)
                     Utilities.show_error("Start Server",
